/*____________________________________________________________________________
	
	FreeAmp - The Free MP3 Player

	Portions Copyright (C) 1998-1999 EMusic.com

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
	
	$Id: debug.h,v 1.5 2000/05/25 18:21:24 ijr Exp $
____________________________________________________________________________*/

#ifndef INCLUDED_DEBUG_H_
#define INCLUDED_DEBUG_H_

void debug_string(char*);

void DebugInit_v(void);
void Debug_v(const char * format, ...);

#endif /* _DEBUG_H_ */
